# NAME

casl - simple implementation of CASL II assembler/COMET II simulator written in Python

# WHAT IS CASL?

*casl* is simple implementation of CASL II assembler and COMET II simulator
written in Python.  The CASL II assembler and the COMET II simulator are
designed for users to study principle operations of computers.  In particular,
CASL II and COMET II are used in the qualifying examination called ``Japan
Information-Technology Engineers Examination'' so that these programs should
be valuable for people who would like to acquire this qualification.

Since both the CASL II assembler and the COMET II simulator are written only
in Python, these programs should work on almost all operating systems
including UNIX flavors, Windows, and macOS.

*casl* includes the following programs:

* *casl* - a simple implementation of CASL II assembler
* *comet* - a simple implementation of COMET II simulator

# AVAILABILITY

The latest version of *casl* is available at https://pypi.org/project/casl/ .

# COPYRIGHT

Copyright (C) 2021 Hiroyuki Ohsaki (ohsaki[atmark]lsnl.jp)

# INSTALLATION

``` sh
sudo pip3 install casl
```

# FEEDBACK

If you find any bugs, first check if a newer version exists.  If not, please
send bug report or fixing patch to me via https://github.com/h-ohsaki/casl .
I appreciate your comments and/or suggestions.

# AUTHOR

Hiroyuki Ohsaki <ohsaki[atmark]lsnl.jp>

